@@ -41,6 +41,7 @@ def test_python(raise_on_non_source_class, activation_tester):
                 print(repr(value))
 
             print_r(os.environ.get("VIRTUAL_ENV"))
+            print_r(os.environ.get("VIRTUAL_ENV_PROMPT"))
             print_r(os.environ.get("PATH").split(os.pathsep))
             print_r(sys.path)
 
@@ -51,6 +52,7 @@ def test_python(raise_on_non_source_class, activation_tester):
             exec(content, {{"__file__": file_at}})
 
             print_r(os.environ.get("VIRTUAL_ENV"))
+            print_r(os.environ.get("VIRTUAL_ENV_PROMPT"))
             print_r(os.environ.get("PATH").split(os.pathsep))
             print_r(sys.path)
 
@@ -62,16 +64,19 @@ def test_python(raise_on_non_source_class, activation_tester):
         def assert_output(self, out, raw, tmp_path):  # noqa: ARG002
             out = [literal_eval(i) for i in out]
             assert out[0] is None  # start with VIRTUAL_ENV None
+            assert out[1] is None  # likewise for VIRTUAL_ENV_PROMPT
 
-            prev_path = out[1]
-            prev_sys_path = out[2]
-            assert out[3] == str(self._creator.dest)  # VIRTUAL_ENV now points to the virtual env folder
+            prev_path = out[2]
+            prev_sys_path = out[3]
+            assert out[4] == str(self._creator.dest)  # VIRTUAL_ENV now points to the virtual env folder
 
-            new_path = out[4]  # PATH now starts with bin path of current
+            assert out[5] == str(self._creator.env_name)  # VIRTUAL_ENV_PROMPT now has the env name
+
+            new_path = out[6]  # PATH now starts with bin path of current
             assert ([str(self._creator.bin_dir), *prev_path]) == new_path
 
             # sys path contains the site package at its start
-            new_sys_path = out[5]
+            new_sys_path = out[7]
 
             new_lib_paths = {str(i) for i in self._creator.libs}
             assert prev_sys_path == new_sys_path[len(new_lib_paths) :]
@@ -79,7 +84,7 @@ def test_python(raise_on_non_source_class, activation_tester):
 
             # manage to import from activate site package
             dest = self.norm_path(self._creator.purelib / "pydoc_test.py")
-            found = self.norm_path(out[6])
+            found = self.norm_path(out[8])
             assert found.startswith(dest)
 
         def non_source_activate(self, activate_script):
